@@ -266,6 +266,7 @@ define([
                 case 'frame':
                 case 'chart':
                 case 'profiling':
+                case 'pdf':
                     blockContainer.setSelectBlock(null);
                     blockContainer.createAppsPage(menu, file, config);
                     break;
@@ -303,14 +304,22 @@ define([
 
             var createdBlock = blockContainer.getSelectBlock();
             if (createdBlock) {
-                // apply to original block
-                createdBlock.setState({
-                    apps: {
-                        menu: blockContainer.apps,
-                        code: code,
-                        state: state
-                    }
-                });
+                if (title === 'Snippets') {
+                    // set code
+                    createdBlock.setState({
+                        [STATE_codeLine]: code
+                    });
+                } else if (title === 'Import' || title === 'Variables' || title === 'File' 
+                || title === 'Instance' || title === 'Chart') {
+                    // apply to original block
+                    createdBlock.setState({
+                        apps: {
+                            menu: blockContainer.apps,
+                            code: code,
+                            state: state
+                        }
+                    });
+                }
                 createdBlock.saveState();
             } else {
                 if (title === 'Snippets') {
@@ -371,7 +380,7 @@ define([
         });
 
         /** Apps Menu Apply event */
-        $(document).on('subset_run frame_run', '#vp_appsCode', function(evt) {
+        $(document).on('subset_run frame_run pdf_run', '#vp_appsCode', function(evt) {
             var code = evt.code;
             var title = evt.title;
             var state = evt.state;
